# -*- encoding: utf-8 -*-
# create_date: 2019-08-02
# author: Paradox


from setuptools import setup, find_packages

setup(
    name="paradox_commons",
    version="0.0.1",
    keywords=("pip", "paradox_commons", "paradox_commons"),
    description="Paradox's common methods",
    long_description="This is Paradox's package",
    license="MIT Licence",

    url="https://github.com/13241308289/paradox_common",
    author="ZhangLe",
    author_email="2519960931@qq.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=[]
)
